Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(401)

Unified Diff: content/browser/renderer_host/render_view_host_impl.h

Issue 10171018: Create swapped-out opener RVHs after a process swap. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Remove parameter comments. Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/render_view_host_impl.h
diff --git a/content/browser/renderer_host/render_view_host_impl.h b/content/browser/renderer_host/render_view_host_impl.h
index 19eb9a80eba124bb7fcf113a4bb3b423caa3ec3a..903027d5787746bd5ba39b15054e306ee7672de3 100644
--- a/content/browser/renderer_host/render_view_host_impl.h
+++ b/content/browser/renderer_host/render_view_host_impl.h
@@ -119,10 +119,12 @@ class CONTENT_EXPORT RenderViewHostImpl
// Convenience function, just like RenderViewHost::FromID.
static RenderViewHostImpl* FromID(int render_process_id, int render_view_id);
// routing_id could be a valid route id, or it could be MSG_ROUTING_NONE, in
// which case RenderWidgetHost will create a new one.
//
- // The session storage namespace parameter allows multiple render views and
+ // The |session_storage_namespace| parameter allows multiple render views and
// WebContentses to share the same session storage (part of the WebStorage
// spec) space. This is useful when restoring contentses, but most callers
// should pass in NULL which will cause a new SessionStorageNamespace to be
@@ -131,6 +133,7 @@ class CONTENT_EXPORT RenderViewHostImpl
SiteInstance* instance,
RenderViewHostDelegate* delegate,
int routing_id,
+ bool swapped_out,
SessionStorageNamespace* session_storage_namespace);
virtual ~RenderViewHostImpl();
@@ -225,9 +228,13 @@ class CONTENT_EXPORT RenderViewHostImpl
// Set up the RenderView child process. Virtual because it is overridden by
// TestRenderViewHost. If the |frame_name| parameter is non-empty, it is used
- // as the name of the new top-level frame. If |max_page_id| is larger than
- // -1, the RenderView is told to start issuing page IDs at |max_page_id| + 1.
- virtual bool CreateRenderView(const string16& frame_name, int32 max_page_id);
+ // as the name of the new top-level frame. The |opener_route_id| parameter
+ // indicates which RenderView created this (MSG_ROUTING_NONE if none). If
+ // |max_page_id| is larger than -1, the RenderView is told to start issuing
+ // page IDs at |max_page_id| + 1.
+ virtual bool CreateRenderView(const string16& frame_name,
+ int opener_route_id,
+ int32 max_page_id);
base::TerminationStatus render_view_termination_status() const {
return render_view_termination_status_;
« no previous file with comments | « content/browser/renderer_host/render_view_host_factory.cc ('k') | content/browser/renderer_host/render_view_host_impl.cc » ('j') | no next file with comments »
@@ -119,10 +119,12 @@ class CONTENT_EXPORT RenderViewHostImpl
// Convenience function, just like RenderViewHost::FromID.
static RenderViewHostImpl* FromID(int render_process_id, int render_view_id);
- // routing_id could be a valid route id, or it could be MSG_ROUTING_NONE, in
- // which case RenderWidgetHost will create a new one.
+ // |routing_id| could be a valid route id, or it could be MSG_ROUTING_NONE, in
+ // which case RenderWidgetHost will create a new one. |swapped_out| indicates
+ // whether the view should initially be swapped out (e.g., for an opener
+ // frame being rendered by another process).
//

Powered by Google App Engine
This is Rietveld 408576698